# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.alerts_v1_api import AlertsV1Api


class TestAlertsV1Api(unittest.TestCase):
    """AlertsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = AlertsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_alert(self) -> None:
        """Test case for get_alert

        Get Alert By Id
        """
        pass

    def test_get_alerts_in_workspace(self) -> None:
        """Test case for get_alerts_in_workspace

        Get Workspace Alerts.
        """
        pass

    def test_get_model_alerts(self) -> None:
        """Test case for get_model_alerts

        Get Model Alerts
        """
        pass

    def test_post_model_alerts(self) -> None:
        """Test case for post_model_alerts

        Create Model Alerts
        """
        pass


if __name__ == '__main__':
    unittest.main()
